TestWeatherStation — pywws 13.03_7f9fc90 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »

# TestWeatherStation

Teste la connexion à la station météo.

Ceci est un utilitaire simple pour tester la communication avec la station météo. Si cela ne fonctionne pas, alors il y a un problème qui doit être résolu avant d’essayer tout autre programme. Les problèmes possibles comprennent l’installation incorrecte de libusb ou PyUSB. Un problème moins probable inclu une incompatibilité entre libusb et certains systèmes d’exploitation. Le problème le plus probable est que vous avez oublié de connecter la station météo à votre ordinateur!

    usage: python TestWeatherStation.py [options]
    options are:
          --help           display this help
     -c | --change         display any changes in "fixed block" data
     -d | --decode         display meaningful values instead of raw data
     -h | --history count  display the last "count" readings
     -l | --live           display 'live' data
     -m | --logged         display 'logged' data
     -u | --unknown        display unknown fixed block values
     -v | --verbose        increase amount of reassuring messages
                           (repeat for even more messages e.g. -vvv)

Fonctions

`main`([argv]) |
`raw_dump`(pos, data) |

`TestWeatherStation.` `raw_dump`(pos, data)

`TestWeatherStation.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »